@@ -67,6 +67,10 @@ def get_key(token: str) -> PyJWK:
 def is_authenticated(token: str, signing_key: Optional[str] = None, audience: Optional[str] = None) -> bool:
     """Checks if a token is created by PeachPayments for the right audience.
 
+    Used for the Outbound API call (requests from Partner API to Payment Service Provider).
+    The token is retrieved from the `Authorization` header of the request.
+    It is created with the audience unique for the Payment Service Provider.
+
     Args:
         - token (str) : JWToken to be checked for authentication
 
@@ -105,7 +109,9 @@ _access_token_cache: Dict[str, Dict[str, Any]] = {}
 def get_access_token(client_id: str, client_secret: str, auth_service_generate_access_token_url: str = None) -> str:
     """Retrieve an access token for a client id+secret pair.
 
-    Also caches the token for a period of time to reduce network traffic when creating a token.
+    Returned token is used for the Inbound API call (requests from Payment Service Provider to Partner API).
+    Peach auth service is authenticating the client with the client id and client secret and returning a token.
+    Method also caches the token for a period of time to reduce network traffic.
 
     Args:
        - client_id (str): Application client id
