@@ -311,6 +311,12 @@ class ResultCodes:
     INVALID_STREET = ResultCode(code="800.800.102", name="INVALID_STREET", description="Invalid street")
     INVALID_ZIP = ResultCode(code="800.800.202", name="INVALID_ZIP", description="Invalid zip")
     INVALID_CITY = ResultCode(code="800.800.302", name="INVALID_CITY", description="Invalid city")
+    INVALID_AUTHENTICATION_INFORMATION = ResultCode(
+        code="800.900.300", name="INVALID_AUTHENTICATION_INFORMATION", description="invalid authentication information"
+    )
+    INVALID_UNIQUE_ID = ResultCode(
+        code="100.100.104", name="INVALID_UNIQUE_ID", description="invalid unique id / root unique id"
+    )
     PREVIOUSLY_PENDING_ONLINE_TRANSFER_TRANSACTION_TIMEOUT = ResultCode(
         code="100.395.501",
         name="PREVIOUSLY_PENDING_ONLINE_TRANSFER_TRANSACTION_TIMEOUT",
@@ -348,6 +354,11 @@ class ResultCodes:
     TRANSACTION_DECLINED_BAD_RATING = ResultCode(
         code="100.400.100", name="TRANSACTION_DECLINED_BAD_RATING", description="transaction declined - very bad rating"
     )
+    RISK_REPORT_UNSUCCESSFUL = ResultCode(
+        code="100.400.327",
+        name="RISK_REPORT_UNSUCCESSFUL",
+        description="Risk report unsuccessful",
+    )
     ACCOUNT_BLACKLISTED = ResultCode(code="100.400.121", name="ACCOUNT_BLACKLISTED", description="account blacklisted")
     GATEWAY_ERROR_RESPONSE = ResultCode(
         code="900.100.200", name="GATEWAY_ERROR_RESPONSE", description="error response from connector/acquirer"
@@ -364,6 +375,14 @@ class ResultCodes:
             "invalid transaction flow, the requested function is not applicable for the referenced transaction."
         ),
     )
+    TIMEOUT_UNCERTAIN_RESULT = ResultCode(
+        code="900.100.300", name="TIMEOUT_UNCERTAIN_RESULT", description="timeout, uncertain result"
+    )
+    TIMEOUT_AT_CONNECTORS_OR_ACQUIRER_SIDE = ResultCode(
+        code="900.100.400",
+        name="TIMEOUT_AT_CONNECTORS_OR_ACQUIRER_SIDE",
+        description="timeout at connectors/acquirer side",
+    )
 
     def __init__(self):
         """Set each provided result code by field."""
